Module shim_filesystem

This is used to paste over normal reading of the Rules files and building them into the code for web assembly (WASM) which can’t do file system access. For the latter, the Rules directory should be zipped up.

Note: if files are added or removed, the directory structure needs to be reflected here. This could be automated, but changes are pretty rare and it didn’t seem worth it (this may need to be revisited).

Functions

canonicalize_shim
find_all_dirs_shim
find_files_in_dir_that_ends_with_shim
is_dir_shim
is_file_shim
read_to_string_shim
zip_extract_shim