pub fn compile_rule<F>(str: &str, build_fn: F) -> Result<()>where
    F: FnMut(&Yaml) -> Result<()>,
Given a string that should be Yaml, it calls build_fn with that string. The build function/closure should process the Yaml as appropriate and capture any errors and write them to std_err.