pub struct SpeechRules {
pub pref_manager: Rc<RefCell<PreferenceManager>>,
/* private fields */
}
SpeechRulesWithContext encapsulates a named group of speech rules (e.g, “ClearSpeak”)
along with the preferences to be used for speech.
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
Converts the given value to a
String.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.