pub struct SpeechRulesWithContext<'c, 's: 'c, 'm: 'c> {
    pub inside_spell: bool,
    /* private fields */
}
SpeechRulesWithContext encapsulates a named group of speech rules (e.g, “ClearSpeak”) along with the preferences to be used for speech. Because speech rules can define variables, there is also a context that is carried with them

Fields

inside_spell: bool

Implementations

We track three different lifetimes: ’c – the lifetime of the context and mathml ’s – the lifetime of the speech rules (which is static) ’r – the lifetime of the reference (this seems to be key to keep the rust memory checker happy)

Lookup unicode “pronunciation” of char. Note: TTS is not supported here (not needed and a little less efficient)