pub fn init_panic_handler()Expand description
Initialize the panic handler to catch panics and store the message, file, and line number in PANIC_INFO.
pub fn init_panic_handler()Initialize the panic handler to catch panics and store the message, file, and line number in PANIC_INFO.