Function libmathcat::speech::compile_rule
source · Expand description
Given a string that should be Yaml, it calls build_fn with that string.
The build function/closure should process the Yaml as appropriate and capture any errors and write them to std_err.